@@ -3,7 +3,7 @@ package App::GoogleSearchUtils;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-10-01'; # DATE
 our $DIST = 'App-GoogleSearchUtils'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
@@ -26,6 +26,10 @@ $SPEC{google_search} = {
             pos => 0,
             slurpy => 1,
         },
+        delay => {
+            summary => 'Delay between opening each query',
+            schema => 'duration*',
+        },
         prepend => {
             summary => 'String to add at the beginning of each query',
             schema => 'str*',
@@ -83,6 +87,10 @@ sub google_search {
     my $i = -1;
     for my $query0 (@{ $args{queries} }) {
         $i++;
+        if ($i > 0 && $args{delay}) {
+            log_trace "Sleeping %s second(s) ...", $args{delay};
+            sleep $args{delay};
+        }
         my $query = join(
             "",
             defined($args{prepend}) ? $args{prepend} : "",
@@ -113,7 +121,7 @@ App::GoogleSearchUtils - CLI utilites related to google searching
 
 =head1 VERSION
 
-This document describes version 0.003 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2020-10-01.
+This document describes version 0.004 of App::GoogleSearchUtils (from Perl distribution App-GoogleSearchUtils), released on 2020-10-01.
 
 =head1 SYNOPSIS
 
@@ -146,6 +154,10 @@ Arguments ('*' denotes required arguments):
 
 String to add at the end of each query.
 
+=item * B<delay> => I<duration>
+
+Delay between opening each query.
+
 =item * B<num> => I<posint> (default: 100)
 
 Number of results per page.
